@@ -193,11 +193,6 @@ QByteArray Polkit1Backend::callerID() const
     return QDBusConnection::systemBus().baseService().toUtf8();
 }
 
-AuthBackend::ExtraCallerIDVerificationMethod Polkit1Backend::extraCallerIDVerificationMethod() const
-{
-    return VerifyAgainstDBusServiceName;
-}
-
 bool Polkit1Backend::isCallerAuthorized(const QString &action, const QByteArray &callerID, const QVariantMap &details)
 {
     PolkitQt1::SystemBusNameSubject subject(QString::fromUtf8(callerID));
@@ -265,3 +260,5 @@ QVariantMap Polkit1Backend::backendDetails(const DetailsMap &details)
 } // namespace Auth
 
 #include "Polkit1Backend.moc"
+
+#include "moc_Polkit1Backend.cpp"
